"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var classNames = require("classnames");
var tabbable = require("tabbable");
var ts_keycode_enum_1 = require("ts-keycode-enum");
var Dialog = /** @class */ (function (_super) {
    __extends(Dialog, _super);
    function Dialog() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.setDialogRef = function (ref) {
            _this.dialogRef = ref;
        };
        _this.setFocusIfVisible = function () {
            // Needed when the root level element is animated
            if (_this.props.isVisible === true) {
                _this.dialogRef.focus();
            }
        };
        _this.onKeyDown = function (event) {
            if (_this.props.onKeyDown != null && _this.props.onKeyDown(event)) {
                return;
            }
            if (_this.handleEscapeClick(event)) {
                return;
            }
            if (_this.handleTabClick(event)) {
                return;
            }
        };
        _this.onDialogClick = function (event) {
            event.preventDefault();
            event.stopPropagation();
            _this.dialogRef.focus();
        };
        _this.onBackgroundClick = function (event) {
            if (_this.props.onBackgroundClick) {
                _this.props.onBackgroundClick(event);
            }
        };
        return _this;
    }
    Dialog.prototype.componentDidMount = function () {
        if (this.props.isVisible === true) {
            this.setState({
                previousElementBeforeOpen: document.activeElement
            });
            this.dialogRef.focus();
        }
    };
    Dialog.prototype.componentDidUpdate = function (oldProps) {
        if (this.props.isVisible === true &&
            this.props.isVisible !== oldProps.isVisible) {
            // The dialog is going from not visible to visible
            this.dialogRef.scrollTop = 0;
            this.setState({
                previousElementBeforeOpen: document.activeElement
            });
            this.dialogRef.focus();
        }
        else if (this.props.isVisible === false &&
            this.props.isVisible !== oldProps.isVisible) {
            // The dialog is going from visible to not visible
            var htmlElement = this.state.previousElementBeforeOpen;
            if (htmlElement != null && htmlElement.focus != null) {
                htmlElement.focus();
            }
        }
    };
    Dialog.prototype.render = function () {
        var _a = this.props, isBaseStylesDisabled = _a.isBaseStylesDisabled, onBackgroundClick = _a.onBackgroundClick, isVisible = _a.isVisible, className = _a.className, htmlProps = __rest(_a, ["isBaseStylesDisabled", "onBackgroundClick", "isVisible", "className"]);
        className = classNames({ "sci-react-dialog": isBaseStylesDisabled !== true }, className, { "visible": this.props.isVisible });
        return (React.createElement("div", __assign({}, htmlProps, { className: className, onAnimationEnd: this.setFocusIfVisible, onTransitionEnd: this.setFocusIfVisible }),
            React.createElement("div", { className: "overlay", onClick: this.onBackgroundClick },
                React.createElement("div", { ref: this.setDialogRef, role: "dialog", tabIndex: 1, className: "dialog", onClick: this.onDialogClick, onKeyDown: this.onKeyDown }, this.props.children))));
    };
    Dialog.prototype.handleEscapeClick = function (event) {
        if (event.isDefaultPrevented() || event.keyCode !== ts_keycode_enum_1.Key.Escape) {
            return false;
        }
        event.preventDefault();
        this.onBackgroundClick(event);
        return true;
    };
    Dialog.prototype.handleTabClick = function (event) {
        if (event.isDefaultPrevented() || event.keyCode !== ts_keycode_enum_1.Key.Tab) {
            return false;
        }
        var tabbableElements = tabbable(this.dialogRef);
        var first = tabbableElements[0];
        var last = tabbableElements[tabbableElements.length - 1];
        if (first === undefined) {
            // This has no tabbable elements, set focus back on the dialog itself
            this.dialogRef.focus();
            event.preventDefault();
        }
        else if ((document.activeElement === this.dialogRef || document.activeElement === last) && !event.shiftKey) {
            first.focus();
            event.preventDefault();
        }
        else if ((document.activeElement === this.dialogRef || document.activeElement === first) && event.shiftKey) {
            last.focus();
            event.preventDefault();
        }
        return true;
    };
    return Dialog;
}(React.Component));
exports.Dialog = Dialog;
//# sourceMappingURL=component.js.map